@@ -1,7 +1,7 @@
 import pandas as pd
 
 
-def improve_dlc_csv(csv_file, type=None):
+def improve_dlc_csv(csv_file, trial_type=None):
 
     df = pd.read_csv(csv_file)
 
@@ -9,13 +9,13 @@ def improve_dlc_csv(csv_file, type=None):
 
     n = len(df)
 
-    if type is None:
+    if trial_type is None:
         print("Please specify type!")
 
-    if type is 'owner':
+    if trial_type == 'owner':
         time = 1020
 
-    if type is 'cat':
+    if trial_type == 'cat':
         time = 600
 
     f = n / time
@@ -30,10 +30,10 @@ def improve_dlc_csv(csv_file, type=None):
 
     trials = []
 
-    if type is None:
+    if trial_type is None:
         print("Please specify type!")
 
-    elif type is "owner":
+    elif trial_type == "owner":
 
         for i in indx:
             k = 300
@@ -49,7 +49,7 @@ def improve_dlc_csv(csv_file, type=None):
             elif k + j * 3 < i <= k + j * 4:
                 trials.append('Second Urine')
 
-    elif type is "cat":
+    elif trial_type == "cat":
         t = 120
         for i in indx:
             if i < t:
