@@ -1,5 +1,4 @@
 from scipy.stats import mannwhitneyu
-from numpy import mean
 import pandas as pd
 
 
@@ -8,9 +7,9 @@ def roi_calc_mw(data_file, voi):
     df = pd.read_csv(data_file)
 
     trial_names = [
-        'No treatment', 'Cat alone (1)', 'First saline', 'Cat alone (2)',
-        'First urine', 'Cat alone (3)', 'Second saline', 'Cat alone (4)',
-        'Second urine', 'Cat alone (5)'
+        'No treatment', 'Cat alone (1)', 'First Saline', 'Cat alone (2)',
+        'First Urine', 'Cat alone (3)', 'Second Saline', 'Cat alone (4)',
+        'Second Urine', 'Cat alone (5)'
     ]
 
     for j in ['walls', 'middle']:
